@@ -1,7 +1,7 @@
 package Bencher::Scenarios::ShellGuess;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-07-31'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Scenarios to benchmark Shell::Guess
@@ -18,7 +18,7 @@ Bencher::Scenarios::ShellGuess - Scenarios to benchmark Shell::Guess
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenarios::ShellGuess (from Perl distribution Bencher-Scenarios-ShellGuess), released on 2017-01-25.
+This document describes version 0.003 of Bencher::Scenarios::ShellGuess (from Perl distribution Bencher-Scenarios-ShellGuess), released on 2021-07-31.
 
 =head1 DESCRIPTION
 
@@ -32,6 +32,12 @@ This distribution contains the following L<Bencher> scenario modules:
 
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (@pc-office)
+
+perlancar (@pc-office) <perlancar@gmail.com>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-ShellGuess>.
@@ -54,7 +60,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
